@@ -6,6 +6,7 @@ from django.utils.http import urlsafe_base64_encode, urlsafe_base64_decode
 from django.utils.translation import ugettext_lazy as _
 from incuna_mail import send
 from rest_framework import generics, renderers, response, status, views
+from rest_framework.authtoken.models import Token
 from rest_framework.authtoken.views import ObtainAuthToken
 from rest_framework.permissions import AllowAny, IsAuthenticated
 
@@ -18,11 +19,19 @@ User = get_user_model()
 class GetToken(ObtainAuthToken):
     renderer_classes = (renderers.JSONRenderer, renderers.BrowsableAPIRenderer)
 
+    def delete(self, request, *args, **kwargs):
+        try:
+            token = Token.objects.get(user=request.user)
+        except Token.DoesNotExist:
+            pass
+        else:
+            token.delete()
+        return response.Response(status=status.HTTP_204_NO_CONTENT)
+
 
 class UserRegister(generics.CreateAPIView):
     serializer_class = serializers.RegistrationSerializer
     permission_classes = [permissions.IsNotAuthenticated]
-    ok_message = _('Your account has been created and an activation link sent to your email address. Please check your email to continue.')
 
     def create(self, request, *args, **kwargs):
         serializer = self.get_serializer(data=request.DATA, files=request.FILES)
@@ -32,9 +41,14 @@ class UserRegister(generics.CreateAPIView):
                 serializer.errors, status=status.HTTP_400_BAD_REQUEST)
 
         serializer.save()
+        if serializer.object.email_verification_required:
+            serializer.object.send_validation_email()
+            ok_message = _('Your account has been created and an activation link sent to your email address. Please check your email to continue.')
+        else:
+            ok_message = _('Your account has been created.')
 
         return response.Response(
-            data={'data': self.ok_message},
+            data={'data': ok_message},
             status=status.HTTP_201_CREATED,
         )
 
@@ -114,15 +128,20 @@ class PasswordChange(generics.UpdateAPIView):
 
 class VerifyAccountView(OneTimeUseAPIMixin, views.APIView):
     permission_classes = [AllowAny]
+    ok_message = _('Your account has been verified.')
 
     def post(self, request, *args, **kwargs):
-        if self.user.verified_email:
+        if not self.user.email_verification_required:
             return response.Response(status=status.HTTP_403_FORBIDDEN)
 
-        self.user.verified_email = True
+        self.user.email_verification_required = False
         self.user.is_active = True
         self.user.save()
-        return response.Response(status=status.HTTP_200_OK)
+
+        return response.Response(
+            data={'data': self.ok_message},
+            status=status.HTTP_201_CREATED,
+        )
 
 
 class ProfileDetail(generics.RetrieveUpdateAPIView):
